package forum.dao;

import java.sql.*;

/**
 * Un objet capable de créer des connections à la base de données.
 * Les informations sont stockées en dur. Il ne faut <b>jamais</b> le faire dans 
 * un vrai programme. Mais d'un autre côté, le TP ne porte pas sur la configuration d'un 
 * serveur JEE, et en plus dans une architecture un peu plus élaborée, vous aurez de meilleurs 
 * outils pour gérer le problème.
 */
public class ConnectionFactory {
    private static final ConnectionFactory instance= new ConnectionFactory();

    /**
     * Modifiez l'URL si vous travaillez sous Windows !
     */
    private String url = "jdbc:h2:tcp://localhost//tmp/forum";
    private String login = "sa";
    private String password = "sa";

    public static ConnectionFactory getInstance() {
        return instance;
    }

    /**
     * @return the login
     */
    public String getLogin() {
        return login;
    }
    /**
     * @return the password
     */
    public String getPassword() {
        return password;
    }
    /**
     * @return the url
     */
    public String getUrl() {
        return url;
    }

    /**
     * Crée une nouvelle connection.
     * 
     * @throws SQLException
     */
    public Connection buildConnection() throws SQLException {
        return DriverManager.getConnection(url, login, password);
    }
}